<?php

/**
 * ogenix functions for getting inline styles from theme customizer
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package ogenix
 */

if (!function_exists('ogenix_theme_customizer_styles')) :
	function ogenix_theme_customizer_styles()
	{

		// ogenix color option

		$ogenix_inline_style = '';
		$ogenix_inline_style .= ':root {
			--ogenix-primary: ' . get_theme_mod('theme_primary_color', sanitize_hex_color('#ffcd1e')) . ';
			--ogenix-primary-rgb: ' . ogenix_hex_to_rgb(get_theme_mod('theme_primary_color', sanitize_hex_color('#ffcd1e'))) . ';
			
			--ogenix-base: ' . get_theme_mod('theme_base_color', sanitize_hex_color('#1f6306')) . ';
			--ogenix-base-rgb: ' . ogenix_hex_to_rgb(get_theme_mod('theme_base_color', sanitize_hex_color('#1f6306'))) . ';

			--ogenix-black: ' . get_theme_mod('theme_black_color', sanitize_hex_color('#0e2207')) . ';
			--ogenix-black-rgb: ' . ogenix_hex_to_rgb(get_theme_mod('theme_black_color', sanitize_hex_color('#0e2207'))) . ';
		}';

		$ogenix_inner_banner_bg = get_theme_mod('page_header_bg_image');
		$ogenix_inline_style .= '.page-header-bg { background-image: url(' . $ogenix_inner_banner_bg . '); } ';

		$ogenix_preloader_icon = get_theme_mod('preloader_image');
		if ($ogenix_preloader_icon) {
			$ogenix_inline_style .= '.preloader .preloader__image { background-image: url(' . $ogenix_preloader_icon . '); } ';
		}
		$ogenix_page_header_bottom_bg = get_theme_mod('page_header_bottom_bg_image');

		$ogenix_inline_style .= '.page-header__ripped-paper { background-image: url(' . $ogenix_page_header_bottom_bg . '); }';

		if (is_page()) {


			$ogenix_page_primary_color = empty(get_post_meta(get_the_ID(), 'ogenix_primary_color', true)) ? get_theme_mod('theme_primary_color', sanitize_hex_color('#ffbd3c')) : get_post_meta(get_the_ID(), 'ogenix_primary_color', true);

			$ogenix_page_base_color = empty(get_post_meta(get_the_ID(), 'ogenix_base_color', true)) ? get_theme_mod('theme_base_color', sanitize_hex_color('#50a72c')) : get_post_meta(get_the_ID(), 'ogenix_base_color', true);

			$ogenix_page_black_color = empty(get_post_meta(get_the_ID(), 'ogenix_black_color', true)) ? get_theme_mod('theme_black_color', sanitize_hex_color('#2a491d')) : get_post_meta(get_the_ID(), 'ogenix_black_color', true);

			$ogenix_inline_style .= ':root {
				--ogenix-primary: ' . $ogenix_page_primary_color . ';
				--ogenix-primary-rgb: ' . ogenix_hex_to_rgb($ogenix_page_primary_color) . ';
				--ogenix-base: ' . $ogenix_page_base_color . ';
				--ogenix-base-rgb: ' . ogenix_hex_to_rgb($ogenix_page_base_color) . ';
				--ogenix-black: ' . $ogenix_page_black_color . ';
				--ogenix-black-rgb: ' . ogenix_hex_to_rgb($ogenix_page_black_color) . ';
			}';

			$ogenix_page_header_bg = empty(get_post_meta(get_the_ID(), 'ogenix_set_header_image', true)) ? get_theme_mod('page_header_bg_image') : get_post_meta(get_the_ID(), 'ogenix_set_header_image', true);

			$ogenix_inline_style .= '.page-header-bg { background-image: url(' . $ogenix_page_header_bg . '); }';
		}

		if (is_singular('post')) {
			$ogenix_post_header_bg = empty(get_post_meta(get_the_ID(), 'ogenix_set_header_image', true)) ? get_theme_mod('page_header_bg_image') : get_post_meta(get_the_ID(), 'ogenix_set_header_image', true);

			$ogenix_inline_style .= '.page-header-bg  { background-image: url(' . $ogenix_post_header_bg . '); }';

			$ogenix_post_header_bottom_bg = empty(get_post_meta(get_the_ID(), 'ogenix_set_header_bottom_image', true)) ? get_theme_mod('page_header_bottom_bg_image') : get_post_meta(get_the_ID(), 'ogenix_set_header_bottom_image', true);

			$ogenix_inline_style .= '.page-header__ripped-paper { background-image: url(' . $ogenix_post_header_bottom_bg . '); }';
		}


		wp_add_inline_style('ogenix-style', $ogenix_inline_style);
	}
endif;

add_action('wp_enqueue_scripts', 'ogenix_theme_customizer_styles');
