<?php

/**
 * WooCommerce Compatibility File
 *
 * @link https://woocommerce.com/
 *
 * @package ogenix
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)
 * @link https://github.com/woocommerce/woocommerce/wiki/Declaring-WooCommerce-support-in-themes
 *
 * @return void
 */

function ogenix_woocommerce_setup()
{
	add_theme_support(
		'woocommerce',
		array(
			'thumbnail_image_width' => 270,
			'single_image_width'    => 570,
			'product_grid'          => array(
				'default_rows'    => 3,
				'min_rows'        => 1,
				'default_columns' => 3,
				'min_columns'     => 1,
				'max_columns'     => 6,
			),
		)
	);
	add_theme_support('wc-product-gallery-zoom');
	add_theme_support('wc-product-gallery-lightbox');
	add_theme_support('wc-product-gallery-slider');
}
add_action('after_setup_theme', 'ogenix_woocommerce_setup');


/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function ogenix_woocommerce_scripts()
{
	$font_path   = WC()->plugin_url() . '/assets/fonts/';
	$inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';

	wp_add_inline_style('ogenix-style', $inline_font);
}
add_action('wp_enqueue_scripts', 'ogenix_woocommerce_scripts');

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function ogenix_woocommerce_active_body_class($classes)
{
	$classes[] = 'woocommerce-active';

	return $classes;
}
add_filter('body_class', 'ogenix_woocommerce_active_body_class');




/**
 * Disable the default WooCommerce stylesheet.
 *
 * Removing the default WooCommerce stylesheet and enqueing your own will
 * protect you during WooCommerce core updates.
 *
 * @link https://docs.woocommerce.com/document/disable-the-default-stylesheet/
 */

add_filter('woocommerce_enqueue_styles', '__return_empty_array');


//shop page
remove_action('woocommerce_before_shop_loop', 'woocommerce_output_all_notices', 10);
remove_action('woocommerce_before_shop_loop', 'woocommerce_result_count', 20);
remove_action('woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30);

remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);
remove_action('woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10);
remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);

remove_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10);

remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);
remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);

remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);

// shop main or archive  before shop hook
add_action('woocommerce_before_shop_loop', 'ogenix_woocommerce_filter_wrapper', 20);
// woocommerce filter wrapper hook function
if (!function_exists('ogenix_woocommerce_filter_wrapper')) {
	function ogenix_woocommerce_filter_wrapper()
	{ ?>
		<div class="row">
			<div class="col-xl-12">
				<div class="product__showing-result">
					<div class="product__showing-text-box">
						<?php echo woocommerce_result_count(); ?>
					</div>
					<div class="product__menu-showing-sort">
						<ul class="nav nav-tabs product__list-grid-tabs ml-0" id="productListGridTab" role="tablist">
							<li class="nav-item" role="presentation">
								<button class="nav-link active" id="product-grid-tab" data-bs-toggle="tab" data-bs-target="#product-grid" type="button" role="tab" aria-controls="product-grid" aria-selected="true"><span class="icon-menu"></span></button>
							</li>
							<li class="nav-item" role="presentation">
								<button class="nav-link" id="product-list-tab" data-bs-toggle="tab" data-bs-target="#product-list" type="button" role="tab" aria-controls="product-list" aria-selected="false"><span class="icon-list"></span></button>
							</li>
						</ul>
						<div class="product__showing-sort">
							<div class="select-box">
								<?php echo woocommerce_catalog_ordering(); ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	<?php }
}

add_action('woocommerce_before_shop_loop', 'ogenix_woocommerce_tab_content_wrapper_start', 35);

function ogenix_woocommerce_tab_content_wrapper_start()
{
	echo '<div class="tab-content" id="productListGridTabContent">';
}

add_action('ogenix_woocommerce_product_content', 'ogenix_grid_tab_content_cb', 10);

// ogenix grid tab content hook function
if (!function_exists('ogenix_grid_tab_content_cb')) {
	function ogenix_grid_tab_content_cb()
	{
		echo '<!-- Start Product Grid Views -->';

		echo '<div class="tab-pane fade show active" id="product-grid" role="tabpanel" aria-labelledby="product-grid">';
		echo '<div class="product__all">';
		echo '<div class="row">';

		woocommerce_product_loop_start();

		if (wc_get_loop_prop('total')) {
			while (have_posts()) {
				the_post();

				/**
				 * Hook: woocommerce_shop_loop.
				 */
				do_action('woocommerce_shop_loop');

				wc_get_template_part('content', 'product');
			}
		}

		woocommerce_product_loop_end();
		echo '</div>';
		echo '</div>';
		echo '</div>';

		echo '<!-- End Grid -->';
	}
}

// ogenix loop grid product thumbnail hook function
if (!function_exists('ogenix_loop_product_thumbnail')) {
	function ogenix_loop_product_thumbnail()
	{
		global $product;
	?>
		<!--Product All Single Start-->
		<div class="product__all-single">
			<div class="product__all-single-inner">
				<div class="product__all-img">
					<img src="<?php echo esc_url(get_the_post_thumbnail_url()); ?>" alt="<?php echo esc_attr(get_bloginfo('name')); ?>">
				</div>
				<div class="product__all-content">
					<div class="product__all-review">
						<?php echo woocommerce_template_loop_rating(); ?>
					</div>
					<h4 class="product__all-title"><a href="<?php echo esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a></h4>
					<p class="product__all-price"><?php echo woocommerce_template_loop_price(); ?></p>
					<div class="product__add-to-cart">
						<?php
						global $product;
						$ogenix_ajax_cart_class = (get_option('woocommerce_enable_ajax_add_to_cart') == 'yes' ? 'ogenix_ajax' : '');
						if ($product->is_type('variable')) {

							echo sprintf(
								'<a href="%s" class="%s">%s</a>',
								esc_url($product->add_to_cart_url()),
								esc_attr(implode(' ', array_filter(array(
									'button', 'product_type_' . $product->get_type(),
									'thm-btn product__all-btn add_to_cart_button'
								)))),
								esc_html($product->add_to_cart_text())
							);
						} else {
							echo sprintf(
								'<a href="%s" data-quantity="1" class="%s" %s>%s</a>',
								esc_url($product->add_to_cart_url()),
								esc_attr(implode(' ', array_filter(array(
									'button', 'product_type_' . $product->get_type(),
									$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
									$product->supports('ajax_add_to_cart') ? 'thm-btn product__all-btn add_to_cart_button ajax_add_to_cart' : 'thm-btn shop-one__cart add_to_cart_button ',
									$ogenix_ajax_cart_class
								)))),
								wc_implode_html_attributes(array(
									'data-product_id'  => $product->get_id(),
									'data-product_sku' => $product->get_sku(),
									'aria-label'       => $product->add_to_cart_description(),
									'rel'              => 'nofollow',
								)),
								esc_html($product->add_to_cart_text())
							);
						}
						?>
					</div>
				</div>
				<div class="products__all-icon-boxes">
					<?php
					if (class_exists('WPCleverWoosw')) {
						echo do_shortcode('[woosw]');
					}
					?>

					<?php
					if (class_exists('WPCleverWoosq')) {
						echo do_shortcode('[woosq]');
					}
					?>
				</div>
			</div>
		</div>
		<!--Product All Single End-->
	<?php }
}

//  woocommerce shop or archive product thumbnail content
add_action('woocommerce_before_shop_loop_item', 'ogenix_loop_product_thumbnail', 10);

// ogenix list tab content hook function
if (!function_exists('ogenix_list_tab_content_cb')) {
	function ogenix_list_tab_content_cb()
	{
		echo '<!-- List -->';
		echo '<div class="tab-pane fade " id="product-list" role="tabpanel" aria-labelledby="product-list">';
		echo '<div class="product-list__inner">';
		woocommerce_product_loop_start();

		if (wc_get_loop_prop('total')) {
			while (have_posts()) {
				the_post();
				/**
				 * Hook: woocommerce_shop_loop.
				 */
				do_action('woocommerce_shop_loop');

				wc_get_template_part('content-horizontal', 'product');
			}
			wp_reset_postdata();
		}
		woocommerce_product_loop_end();
		echo '</div>';
		echo '</div>';
		echo '<!-- End List -->';
	}
}

add_action('ogenix_woocommerce_product_content', 'ogenix_list_tab_content_cb', 20);

// ogenix loop list product thumbnail hook function
if (!function_exists('ogenix_loop_horizontal_product_thumbnail')) {
	function ogenix_loop_horizontal_product_thumbnail()
	{
		global $product;
		$product_id = $product->get_id();
		$product_instance = wc_get_product($product_id);
		$product_short_description = $product_instance->get_short_description();
	?>
		<!--Product All Single Start-->
		<li class="product-list__single">
			<div class="product-list__single-inner">
				<div class="product-list__img-box">
					<div class="product-list__img">
						<img src="<?php echo esc_url(get_the_post_thumbnail_url()); ?>" alt="<?php echo esc_attr(get_bloginfo('name')); ?>">
					</div>
					<div class="product-list__icon-boxes">
						<?php
						if (class_exists('WPCleverWoosw')) {
							echo do_shortcode('[woosw]');
						}
						?>

						<?php
						if (class_exists('WPCleverWoosq')) {
							echo do_shortcode('[woosq]');
						}
						?>
					</div>
				</div>
				<div class="product-list__content">
					<div class="product-list__review">
						<?php echo woocommerce_template_loop_rating(); ?>
					</div>
					<h4 class="product-list__title"><a href="<?php echo esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a></h4>
					<p class="product-list__price"><?php echo woocommerce_template_loop_price(); ?></p>
					<p class="product-list__text"><?php echo esc_html($product_short_description); ?></p>
					<div class="product__add-to-cart">
						<?php
						global $product;
						$ogenix_ajax_cart_class = (get_option('woocommerce_enable_ajax_add_to_cart') == 'yes' ? 'ogenix_ajax' : '');
						if ($product->is_type('variable')) {

							echo sprintf(
								'<a href="%s" class="%s">%s</a>',
								esc_url($product->add_to_cart_url()),
								esc_attr(implode(' ', array_filter(array(
									'button', 'product_type_' . $product->get_type(),
									'thm-btn product__all-btn add_to_cart_button'
								)))),
								esc_html($product->add_to_cart_text())
							);
						} else {
							echo sprintf(
								'<a href="%s" data-quantity="1" class="%s" %s>%s</a>',
								esc_url($product->add_to_cart_url()),
								esc_attr(implode(' ', array_filter(array(
									'button', 'product_type_' . $product->get_type(),
									$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
									$product->supports('ajax_add_to_cart') ? 'thm-btn product-list__btn add_to_cart_button ajax_add_to_cart' : 'thm-btn shop-one__cart add_to_cart_button ',
									$ogenix_ajax_cart_class
								)))),
								wc_implode_html_attributes(array(
									'data-product_id'  => $product->get_id(),
									'data-product_sku' => $product->get_sku(),
									'aria-label'       => $product->add_to_cart_description(),
									'rel'              => 'nofollow',
								)),
								esc_html($product->add_to_cart_text())
							);
						}
						?>
					</div>
				</div>
			</div>
		</li>
		<!--Product All Single End-->
	<?php }
}


// ogenix shop loop horizontal product thumbnail hook
add_action('woocommerce_before_shop_horizontal_loop_item', 'ogenix_loop_horizontal_product_thumbnail', 10);

// ogenix shop loop content wrappper end
add_action('woocommerce_after_shop_loop', 'ogenix_woocommerce_tab_content_wrapper_end', 35);

function ogenix_woocommerce_tab_content_wrapper_end()
{
	echo '</div>';
}

//single page
remove_action('woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_title', 5);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50);


remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10);
remove_action('woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15);
remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);




add_action('woocommerce_single_product_summary', 'ogenix_product_details_title_markup_start');
function ogenix_product_details_title_markup_start()
{ ?>
	<div class="product-details__top">
	<?php
}

add_action('woocommerce_single_product_summary', 'ogenix_template_single_title');
function ogenix_template_single_title()
{
	global $product;
	?>
		<h3 class="product-details__title"><?php the_title(); ?><?php echo woocommerce_template_loop_price(); ?></h3>
	<?php
}


add_action('woocommerce_single_product_summary', 'ogenix_product_details_title_markup_end');
function ogenix_product_details_title_markup_end()
{ ?>
	</div>
<?php
}


add_action('woocommerce_single_product_summary', 'ogenix_template_single_rating');
function ogenix_template_single_rating()
{
?>
	<div class="product-details__content__rating">
		<?php wc_get_template('single-product/rating.php'); ?>
	</div>

<?php
}

add_action('woocommerce_single_product_summary', 'ogenix_template_single_excerpt');
function ogenix_template_single_excerpt()
{
?>
	<div class="product-details__content__text">
		<?php wc_get_template('single-product/short-description.php'); ?>
	</div>

<?php
}


add_action('woocommerce_before_add_to_cart_quantity', 'ogenix_add_to_cart_input_markup_start');

function ogenix_add_to_cart_input_markup_start()
{ ?>
	<div class="product-details__quantity">
		<div class="product-details__quantity-title"><?php esc_html_e('Quantity', 'ogenix'); ?></div>
		<!-- /.product-details__quantity -->
	<?php }

add_action('woocommerce_after_add_to_cart_quantity', 'ogenix_add_to_cart_input_markup_end');

function ogenix_add_to_cart_input_markup_end()
{ ?>
	</div>

<?php }

add_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart');

add_action('woocommerce_after_add_to_cart_button', 'ogenix_wishlist');
function ogenix_wishlist()
{
	global $product;
	$id = $product->get_id();
	echo '<div class="product-details__buttons-2">';
	if (class_exists('WPCleverWoosw')) {
		echo do_shortcode('[woosw]');
	}
	echo '</div>';
}

add_action('woocommerce_after_add_to_cart_quantity', 'ogenix_after_add_to_cart_quantity', 99);
function ogenix_after_add_to_cart_quantity()
{ ?>
	<div class="product-details__buttons">
	<?php }

add_action('woocommerce_after_add_to_cart_button', 'ogenix_after_add_to_cart_button', 99);
function ogenix_after_add_to_cart_button()
{
	?>
	</div>
<?php }

add_action('woocommerce_after_single_product', 'ogenix_product_content');

function ogenix_product_content()
{ ?>
	<section class="product-content product-description">
		<h2 class="product-description__title"><?php esc_html_e('Description', 'ogenix'); ?></h2><!-- /.product-description__title -->
		<?php the_content(); ?>
	</section><!-- /.product-content -->
<?php }

function ogenix_register_fields()
{ ?>
	<p class="form-row form-row-first">
		<label for="reg_billing_first_name"><?php _e('First name', 'ogenix'); ?><span class="required">*</span></label>
		<input type="text" class="input-text" name="billing_first_name" id="reg_billing_first_name" value="<?php if (!empty($_POST['billing_first_name'])) esc_attr($_POST['billing_first_name']); ?>" />
	</p>
	<p class="form-row form-row-last">
		<label for="reg_billing_last_name"><?php _e('Last name', 'ogenix'); ?><span class="required">*</span></label>
		<input type="text" class="input-text" name="billing_last_name" id="reg_billing_last_name" value="<?php if (!empty($_POST['billing_last_name'])) esc_attr($_POST['billing_last_name']); ?>" />
	</p>
	<div class="clear"></div>
<?php
}
add_action('woocommerce_register_form_start', 'ogenix_register_fields');

add_filter('woocommerce_checkout_fields', 'ogenix_billing_checkout_fields', 20, 1);
function ogenix_billing_checkout_fields($fields)
{
	$fields['billing']['billing_first_name']['placeholder'] = esc_html__('First Name', 'ogenix');
	$fields['billing']['billing_last_name']['placeholder'] = esc_html__('Last Name', 'ogenix');
	$fields['billing']['billing_company']['placeholder'] = esc_html__('Company name (optional)', 'ogenix');
	$fields['billing']['billing_city']['placeholder'] = esc_html__('Town / City', 'ogenix');
	$fields['billing']['billing_postcode']['placeholder'] = esc_html__('ZIP Code', 'ogenix');
	$fields['billing']['billing_phone']['placeholder'] = esc_html__('Phone', 'ogenix');
	$fields['billing']['billing_email']['placeholder'] = esc_html__('Email', 'ogenix');
	return $fields;
}

add_filter('woocommerce_checkout_fields', 'ogenix_shipping_checkout_fields', 20, 1);
function ogenix_shipping_checkout_fields($fields)
{
	$fields['shipping']['shipping_first_name']['placeholder'] = esc_html__('First Name', 'ogenix');
	$fields['shipping']['shipping_last_name']['placeholder'] = esc_html__('Last Name', 'ogenix');
	$fields['shipping']['shipping_company']['placeholder'] = esc_html__('Company name (optional)', 'ogenix');
	return $fields;
}


// WooCommerce Checkout Fields Hook
add_filter('woocommerce_checkout_fields', 'ogenix_checkout_fields_no_label');

// Our hooked in function - $fields is passed via the filter!
// Action: remove label from $fields
function ogenix_checkout_fields_no_label($fields)
{
	// loop by category
	foreach ($fields as $category => $value) {
		// loop by fields
		foreach ($fields[$category] as $field => $property) {
			// remove label property
			unset($fields[$category][$field]['label']);
		}
	}
	return $fields;
}
